# MGSurvE: Mosquito Gene Surveillance Explorer

MGSurvE is a project oriented towards the optimization of traps' placement in complex heterogeneous landscapes in an effort to minimize the time to detection of genetic variants of interest.

![](./img/demo.jpg)


Developer: [Héctor M. Sánchez C.](https://chipdelmal.github.io/blog/)


<img src="./img/berkeley.jpg" height="25px"> <img src="./img/IHME.jpg" height="25px">  <img src="./img/UCIMI.png" height="25px"> <img src="./img/IGI.png" height="25px"> <img src="./img/DARPA.jpg" height="25px">